Peripherals
===========
MetaWear boards come with several auxiliary features that developers can use to provide feedback to their users such as starting a vibration motion 
when 10,000 steps are taken or turning on the LED if the temperature is outside of a desireable range.  Developers can also enhance the functionality 
of the boards by using the GPIO pins to add additional sensors or devices.

.. toctree::
    :hidden:
    :maxdepth: 1

    gpio
    haptic
    i2c
    ibeacon
    led
    neopixel
    spi
